@@ -40,6 +40,23 @@ class Arkivist:
         self.case_sensitive = True
         self.matches = {}
     
+    def set(self, key, value):
+        """
+            Formats and saves the dictionary into a JSON file.
+            ...
+            Parameters
+            ---
+            key: unique hashable string
+                the key of the entry
+            value: string, integer, float
+                the value of the entry
+        """
+        self.child_key = None
+        self.collection.update({key: value})
+        if self.autosave and self.save_to_file:
+            update_file(self.filepath, self.collection, self.indent, self.sort, self.reverse)
+        return self
+    
     def update(self, data):
         """
             Formats and saves the dictionary into a JSON file.
@@ -54,10 +71,6 @@ class Arkivist:
         if self.autosave and self.save_to_file:
             update_file(self.filepath, self.collection, self.indent, self.sort, self.reverse)
         return self
-    
-    def set(self, data):
-        print("Deprecated function, use update() instead.")
-        return self
 
     def fetch(self, url):
         """
@@ -97,6 +110,21 @@ class Arkivist:
                 pass
         return self
     
+    def pop(self, key):
+        """
+            Remove key-value from the dictionary
+            ...
+            Parameters
+            ---
+            key: str
+                any valid string found in the dictionary
+        """
+        self.child_key = None
+        self.collection.pop(key)
+        if self.autosave and self.save_to_file:
+            update_file(self.filepath, self.collection, self.indent, self.sort, self.reverse)
+        return self
+    
     def invert(self):
         """ Inverts the dictionary """
         self.child_key = None
